/**
 * 加载
 *
 * @author yusangeng@outlook.com
 */
/**
 * 模块资源信息.
 *
 * @interface ModuleInfo
 */
interface ModuleInfo {
    js: Array<string>;
    css: Array<string>;
    umd?: boolean;
    crossOrigin?: string;
}
/**
 * 加载一个完整模块.
 *
 * module中最后一个js会以模拟的AMD格式加载, 如果要导出接口, 最后一个js请使用UMD格式.
 *
 * @export
 * @param {ModuleInfo} module 模块信息
 * @returns {Promise<any>}
 */
export declare function importModule(module: ModuleInfo): Promise<any>;
declare type ImportScriptOptions = {
    umd?: boolean;
    crossOrigin?: string;
};
/**
 * 加载一个js脚本.
 *
 * @export
 * @param {string} url 脚本地址
 * @param {ImportScriptOptions} [options={ umd: true }] 配置项
 * @returns {Promise<any>}
 */
export declare function importScript(url: string, options?: ImportScriptOptions): Promise<any>;
/**
 * 加载一个css文件.
 *
 * @export
 * @param {string} url css地址
 * @returns {Promise<any>}
 */
export declare function importStyle(url: string): Promise<void>;
declare const _default: {
    importModule: typeof importModule;
    importScript: typeof importScript;
    importStyle: typeof importStyle;
};
export default _default;
